Romain Iehl : dsound: Correct field access.

Alexandre Julliard julliard at wine.codeweavers.com
Fri Jul 6 12:59:07 CDT 2007


Module: wine
Branch: master
Commit: 684a121aed556d1c9edf04b7f68cccf88fb945fc
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=684a121aed556d1c9edf04b7f68cccf88fb945fc

Author: Romain Iehl <romain.iehl.wine at gmail.com>
Date:   Thu Jul  5 19:32:18 2007 +0200

dsound: Correct field access.

---

 dlls/dsound/sound3d.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/dlls/dsound/sound3d.c b/dlls/dsound/sound3d.c
index ce7899f..cae1c28 100644
--- a/dlls/dsound/sound3d.c
+++ b/dlls/dsound/sound3d.c
@@ -272,13 +272,13 @@ void DSOUND_Calc3DBuffer(IDirectSoundBufferImpl *dsb)
 	/* FIXME: Doppler Effect disabled since i have no idea which frequency to change and how to do it */
 #if 0	
 	/* doppler shift*/
-	if ((VectorMagnitude(&ds3db.vVelocity) == 0) && (VectorMagnitude(&dsb->device->ds3dl.vVelocity) == 0))
+	if ((VectorMagnitude(&ds3db_ds3db.vVelocity) == 0) && (VectorMagnitude(&dsb->device->ds3dl.vVelocity) == 0))
 	{
 		TRACE("doppler: Buffer and Listener don't have velocities\n");
 	}
 	else
 	{
 		/* calculate length of ds3db.vVelocity component which causes Doppler Effect
 		   NOTE: if buffer moves TOWARDS the listener, it's velocity component is NEGATIVE
 		         if buffer moves AWAY from listener, it's velocity component is POSITIVE */
 		flBufferVel = ProjectVector(&dsb->ds3db_ds3db.vVelocity, &vDistance);
@@ -272,13 +272,13 @@ void DSOUND_Calc3DBuffer(IDirectSoundBufferImpl *dsb)
 	else
 	{
-		/* calculate length of ds3db.vVelocity component which causes Doppler Effect
+		/* calculate length of ds3db_ds3db.vVelocity component which causes Doppler Effect
 		   NOTE: if buffer moves TOWARDS the listener, it's velocity component is NEGATIVE
 		         if buffer moves AWAY from listener, it's velocity component is POSITIVE */




More information about the wine-cvs mailing list